@@ -17,6 +17,12 @@ sub new {
     return $self;
 }
 
+sub build_requires {
+    return +{
+	'Test::More'	=> 0.88,	# Because of done_testing().
+    };
+}
+
 sub distribution {
     my ( $self ) = @_;
     return $self->{distribution};
@@ -78,6 +84,16 @@ This class supports the following public methods:
 
 This method instantiates the class.
 
+=head2 build_requires
+
+ use YAML;
+ print Dump( $meta->build_requires() );
+
+This method computes and returns a reference to a hash describing the
+modules required to build the C<Astro::Coord::ECI> package, suitable for
+use in a F<Build.PL> C<build_requires> key, or a F<Makefile.PL>
+C<< {META_MERGE}->{build_requires} >> key.
+
 =head2 distribution
 
  if ( $meta->distribution() ) {
@@ -133,7 +149,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010, Thomas R. Wyant, III
+Copyright (C) 2010-2011 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
